timetokentools.TimeTokenMaker
=============================

.. inheritance-diagram:: abjad.tools.timetokentools.TimeTokenMaker.TimeTokenMaker.TimeTokenMaker
   :private-bases:

.. autoclass:: abjad.tools.timetokentools.TimeTokenMaker.TimeTokenMaker.TimeTokenMaker

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.timetokentools.TimeTokenMaker.TimeTokenMaker.TimeTokenMaker.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Methods
-------

.. automethod:: abjad.tools.timetokentools.TimeTokenMaker.TimeTokenMaker.TimeTokenMaker.reverse

Special Methods
---------------

.. automethod:: abjad.tools.timetokentools.TimeTokenMaker.TimeTokenMaker.TimeTokenMaker.__call__

.. automethod:: abjad.tools.timetokentools.TimeTokenMaker.TimeTokenMaker.TimeTokenMaker.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.timetokentools.TimeTokenMaker.TimeTokenMaker.TimeTokenMaker.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.timetokentools.TimeTokenMaker.TimeTokenMaker.TimeTokenMaker.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.timetokentools.TimeTokenMaker.TimeTokenMaker.TimeTokenMaker.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.timetokentools.TimeTokenMaker.TimeTokenMaker.TimeTokenMaker.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.timetokentools.TimeTokenMaker.TimeTokenMaker.TimeTokenMaker.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.timetokentools.TimeTokenMaker.TimeTokenMaker.TimeTokenMaker.__repr__
